export interface Json2htmlAttr {
    [key: string]: string | number | null;
}
export declare type Json2htmlBody = (Json2htmlRef | string)[] | Json2htmlRef | string;
export interface Json2htmlRef {
    /** tag name */
    tag: string;
    /** attributes */
    attrs?: Json2htmlAttr;
    /** content of tag */
    body?: Json2htmlBody;
    /** inline : override formatting option for this element and these children */
    inline?: boolean;
    /** autoclose (XML only) */
    autoclose?: boolean;
}
export interface Json2htmlOptions {
    /**
     * format of the rendered structure:
     * * `inline`: all on one line without space
     * * `multiline`: structure sur plusieur lignes avec indentation possible
     */
    formatting?: 'inline' | 'multiline';
    /** type d'indentation `space` or `tab` */
    spaceType?: 'space' | 'tab';
    /** size of each level of the indentation  */
    spaceLength?: number;
    /** size of the indentation before each line */
    spaceBase?: number;
    /** maximum number of characters for a line */
    /**
     * attribute alignment:
     * * `inline`: no alignment
     * * `space`: alignment with higher level
     * * `alignTag`: alignment with the tag
     * * `alignFirstAttr`: alignment with the first attribute
     */
    attrPosition?: 'inline' | 'space' | 'alignTag' | 'alignFirstAttr';
    /** Format of the targeted structure */
    type?: 'html' | 'xml';
    /** in XML mode, auto generated tag if the only text alongside other tags */
    xmlDefaultTag?: string;
    /** active of not en indentation. If false, these options are ignored : `spaceType`, `spaceLength` */
    indent?: boolean;
    /** list of HTML tags without content */
    noContentTags?: string[];
}
export declare class Json2html {
    json: Json2htmlRef | Json2htmlRef[];
    readonly options: Json2htmlOptions;
    /**
     * @param json one ou list of node data
     * @param option formating options
     */
    constructor(json: Json2htmlRef | Json2htmlRef[], option?: Json2htmlOptions);
    /**
     * rendering in string
     */
    toString(): string;
    /**
     * generation in string for a node (tag with attributes and content)
     * @param lvl node level
     * @param json node data
     * @returns render of node
     */
    private _generate;
    /**
     * attributes list generation
     * @param lvl level node
     * @param json node data
     * @returns attributes tag
     */
    private _generateAttrs;
    /**
     * tag body generation
     * @param lvl level node
     * @param json node data
     * @returns render of body
     */
    private _generateBody;
    /**
     * tag body generation for one node
     * @param lvl level node
     * @param element node data or string
     * @param onlyOne body this an unique node
     * @returns render of body
     */
    private _generateBodyElement;
    /**
     * if multiline rendering
     */
    private _hasMultiline;
    /**
     * calculating the number of spaces for indentation
     * @param lvl level
     * @param addition space of space (only space, no tabulation)
     * @returns space
     */
    private _getSpacing;
}
